import { Autocomplete, Circle, Cluster, DrawingManager, HeatmapLayer, InfoWindow, KmlLayer, MapLayer, Marker, Polygon, Polyline, Rectangle, StreetViewPanorama } from '../components';
import { IGmapVueElementOptions, IGmapVuePluginOptions, ILoadPluginOptions } from '../interfaces';
import { Emitter, EventType } from 'mitt';
import { ComponentOptions, Ref } from 'vue';
/** @public */
export type TGlobalGoogleObject = Partial<typeof google>;
export type TGoogleMapsAPIInitializerFn = (options: ILoadPluginOptions) => void;
export interface IGmvComponents {
    Autocomplete: typeof Autocomplete;
    Circle: typeof Circle;
    Cluster: typeof Cluster;
    DrawingManager: typeof DrawingManager;
    HeatmapLayer: typeof HeatmapLayer;
    InfoWindow: typeof InfoWindow;
    KmlLayer: typeof KmlLayer;
    MapLayer: typeof MapLayer;
    Marker: typeof Marker;
    Polyline: typeof Polyline;
    Polygon: typeof Polygon;
    Rectangle: typeof Rectangle;
    StreetViewPanorama: typeof StreetViewPanorama;
}
export interface IGmvSharedComposables {
    useMapPromise: () => Promise<google.maps.Map | undefined>;
    useResizeBus: () => {
        currentResizeBus: Ref<Emitter<Record<EventType, unknown>> | undefined>;
        _resizeCallback: () => void;
        _delayedResizeCallback: () => Promise<void>;
    };
    useGoogleMapsApiPromiseLazy: () => Promise<unknown>;
    useStreetViewPanoramaPromise: () => Promise<google.maps.StreetViewPanorama | undefined>;
    usePluginOptions: () => IGmapVuePluginOptions;
}
export interface IGmvUtilities {
    googleMapsApiInitializer: TGoogleMapsAPIInitializerFn;
    pluginComponentBuilder: (providedOptions: IGmapVueElementOptions) => ComponentOptions;
    getGoogleMapsAPI: () => false | TGlobalGoogleObject;
}
export interface IGoogleRecycleObject {
    map: google.maps.Map;
    div: HTMLElement;
}
